fn expr_const_i128(expr: &ContractExpr<'_>) -> Option<i128>Expand description
Extract a contract integer constant small enough for the planner model.
fn expr_const_i128(expr: &ContractExpr<'_>) -> Option<i128>Extract a contract integer constant small enough for the planner model.