fn numeric_term_lower_bound(
term: NumericTerm,
summary: &LoopNumericSummary,
) -> Option<i128>Expand description
Resolve a known lower bound for a numeric term.
fn numeric_term_lower_bound(
term: NumericTerm,
summary: &LoopNumericSummary,
) -> Option<i128>Resolve a known lower bound for a numeric term.