place_is_indirect_write

Function place_is_indirect_write 

fn place_is_indirect_write(place: &Place<'_>) -> bool
Return true when an assignment writes through a pointer/reference.

Such a statement changes memory reachable from a local rather than the local itself, so it is not a local redefinition for this planner.