repeat_for_backedges

Function repeat_for_backedges 

fn repeat_for_backedges(needed_backedges: usize) -> usize
Convert loop backedge distance to PathEnumerator::allow_repeat.

With the current SCC postfix encoding, allow_repeat = 1 reaches the first shallow repeated postfix paths, while the delayed threshold fixtures require three loop backedges and are first exposed at allow_repeat = 2.