pub(crate) struct DataflowDistanceHint {
pub needed_backedges: usize,
}Expand description
A loop-carried dataflow hint.
needed_backedges is measured in loop backedge traversals between the first
loop iteration where a source can be produced and the first iteration where
that source can reach the sink. It is converted to allow_repeat by
repeat_for_backedges.
Fields
needed_backedges: usizeEstimated number of loop backedges required for propagation.
Implementations
Sourceimpl DataflowDistanceHint
impl DataflowDistanceHint
Sourcefn calibrated_repeat(&self) -> usize
fn calibrated_repeat(&self) -> usize
Convert this hint into the path enumerator’s repeat budget.