fn loop_components(graph: &PathGraph<'_>) -> Vec<LoopComponent>Expand description
Extract loop SCCs from PathGraph.
Single-block non-cyclic components are ignored because they do not produce loop-carried state and therefore do not need extra postfix repetition.